pub struct ActorDigestKey {
pub pos: ChunkPos,
}Expand description
Chunk actor digest key used by modern Bedrock entity storage.
Fields
pos: ChunkPosChunk whose digest lists actor ids for the chunk.
Implementations
Sourceimpl ActorDigestKey
impl ActorDigestKey
Sourcepub fn storage_key(self) -> Bytes
pub fn storage_key(self) -> Bytes
Encodes this digest as digp<x><z>[dimension].
Sourcepub fn from_storage_key(key: &[u8]) -> Option<Self>
pub fn from_storage_key(key: &[u8]) -> Option<Self>
Decodes a digp storage key into a digest key.