pub struct BlockTip {
pub block: BlockPos,
pub chunk: ChunkPos,
pub local_x: u8,
pub local_z: u8,
pub surface: Option<SurfaceColumn>,
pub biome_id: Option<u32>,
pub height: Option<i16>,
pub is_slime_chunk: bool,
}Expand description
Block/tip information for one map coordinate.
Fields
block: BlockPosWorld block position for the queried map coordinate.
chunk: ChunkPosChunk containing the queried block.
local_x: u8Local X coordinate within the chunk, in the range 0..16.
local_z: u8Local Z coordinate within the chunk, in the range 0..16.
surface: Option<SurfaceColumn>Surface-column sample for the queried block, when available.
biome_id: Option<u32>Biome id associated with the sampled column.
height: Option<i16>Height in pixels or blocks, depending on the surrounding type.
is_slime_chunk: boolWhether the chunk is a Bedrock slime chunk.