pub struct SelectionStats {
pub bounds: Option<SlimeChunkBounds>,
pub chunk_count: usize,
pub loaded_chunks: usize,
pub missing_chunks: usize,
pub slime_chunks: usize,
pub entity_count: usize,
pub block_entity_count: usize,
pub hardcoded_spawn_area_count: usize,
pub village_count: usize,
}Expand description
Aggregate statistics for a selected chunk area.
Fields
bounds: Option<SlimeChunkBounds>Inclusive chunk bounds for this value.
chunk_count: usizeNumber of chunks represented by these bounds.
loaded_chunks: usizeNumber of chunks with renderable data loaded.
missing_chunks: usizeNumber of expected chunks missing from storage.
slime_chunks: usizeSlime chunk positions in the queried region.
entity_count: usizeNumber of entity overlays found in the selection.
block_entity_count: usizeNumber of block entity overlays found in the selection.
hardcoded_spawn_area_count: usizeNumber of hardcoded spawn area overlays found in the selection.
village_count: usizeNumber of village overlays found in the selection.